/***********************************************************************
This file collects routines from section 3 of the Unix manual which  are
required by PLOT79.  Berkeley 4.2 Unix has these in section 3F, but they
are not implemented in Berkeley 4.1 Unix.  In each case, these  routines
simply  act  as  an  interface  to  corresponding  C  routines  in libc,
supplying arguments by value rather than by reference.  F77  attaches  a
leading  and  trailing underscore to external names, while C uses only a
leading underscore.  These routines therefore have a trailing underscore
so as to be callable from F77 routines.

Because  some  of  these  routines  need  access  to F77's internal data
structures, the source for /src/lib/libi77/fio.h must  be  available  in
order to compile these routines.  This unfortunately makes them unusable
at sites which do not have a Unix source licence.  For this  reason,  we
give the needed structures here:

------------------------------------------------------------------------
typedef struct
{	FILE *ufd;
	char *ufnm;
	long uinode;
	int url;
	flag useek;
	flag ufmt;
	flag uprnt;
	flag ublnk;
	flag uend;
	flag uwrt;
	flag uscrtch;
} unit;

extern unit units[];
------------------------------------------------------------------------

[03-Sep-84]
***********************************************************************/

#define  HZ	60			/* clock frequency in North America */
#ifdef BSD42
#include </usr/src/usr.lib/libI77/fio.h>
#include <sys/time.h>
#else
#include "/src/lib/libi77/fio.h"	/* includes <stdio.h> */
#include <time.h>
#endif
#include <sys/types.h>
#include <sys/times.h>

exit_(code)
int *code;
{
	f_exit();
	exit(*code);
}

fdate_(timstr)
char *timstr;
{
	long clock;

	clock = time((long *) 0);
	(void) strcpy(timstr,ctime(&clock));
}

isatty_(unitno)
int *unitno;
{
	unit *b;

	b = &units[*unitno];
	return(isatty(fileno(b->ufd)));
}

float etime_(tarray)
double tarray[2];	/* arguments are explicitly double because of
			non-uniform aliasing of float with double in C
			implementations */
{
	struct tms buffer;

	times(&buffer);

	tarray[0] = (double) (buffer.tms_utime + buffer.tms_cutime) /
			(double) (HZ);
	tarray[1] = (double) (buffer.tms_stime + buffer.tms_cstime) /
			(double) (HZ);

	return ((float) (tarray[0] + tarray[1]));
}
